import { Component, ViewContainerRef, ChangeDetectionStrategy, NgModule, Injector, Compiler, Input, Inject } from '@angular/core';
import { CommonModule } from '@angular/common';
import { SANDBOX_LOADER } from '../shared/tokens';
var ScenarioComponent = (function () {
    function ScenarioComponent(sandboxLoader, compiler, injector, view) {
        this.sandboxLoader = sandboxLoader;
        this.compiler = compiler;
        this.injector = injector;
        this.view = view;
    }
    Object.defineProperty(ScenarioComponent.prototype, "selectedSandboxAndScenarioKeys", {
        set: function (selectedSandboxAndScenarioKeys) {
            var _this = this;
            this.view.clear();
            if (selectedSandboxAndScenarioKeys) {
                this.sandboxLoader(selectedSandboxAndScenarioKeys.sandboxKey).then(function (sandbox) {
                    if (sandbox) {
                        var scenario = sandbox.scenarios.find(function (s) { return s.key === selectedSandboxAndScenarioKeys.scenarioKey; });
                        if (scenario) {
                            _this.loadScenario(sandbox, scenario, _this.view, _this.injector);
                        }
                    }
                });
            }
        },
        enumerable: true,
        configurable: true
    });
    ScenarioComponent.prototype.loadScenario = function (sandbox, scenario, location, injector) {
        var hostComponent = this.hostComponent(scenario);
        var hostModule = this.hostModule(sandbox, hostComponent);
        this.compiler.clearCache();
        var moduleFactory = this.compiler.compileModuleSync(hostModule);
        var moduleRef = moduleFactory.create(injector);
        var componentFactory = moduleRef.componentFactoryResolver.resolveComponentFactory(hostComponent);
        location.createComponent(componentFactory, location.length, moduleRef.injector);
    };
    ScenarioComponent.prototype.hostComponent = function (scenario) {
        var HostComponent = (function () {
            function HostComponent() {
                Object.assign(this, scenario.context);
            }
            return HostComponent;
        }());
        HostComponent.decorators = [
            { type: Component, args: [{
                        selector: 'host-component',
                        template: scenario.template,
                        styles: scenario.styles,
                        providers: scenario.providers
                    },] },
        ];
        /** @nocollapse */
        HostComponent.ctorParameters = function () { return []; };
        return HostComponent;
    };
    ScenarioComponent.prototype.hostModule = function (sandbox, hostComponent) {
        var imports = sandbox.imports, type = sandbox.type, declarations = sandbox.declarations, providers = sandbox.providers;
        var HostModule = (function () {
            function HostModule() {
            }
            return HostModule;
        }());
        HostModule.decorators = [
            { type: NgModule, args: [{
                        imports: [
                            CommonModule,
                            imports ? imports : []
                        ],
                        declarations: (sandbox.declareComponent ? [type] : []).concat([
                            hostComponent,
                            declarations ? declarations : []
                        ]),
                        providers: providers ? providers : [],
                        entryComponents: [
                            hostComponent
                        ]
                    },] },
        ];
        /** @nocollapse */
        HostModule.ctorParameters = function () { return []; };
        return HostModule;
    };
    return ScenarioComponent;
}());
export { ScenarioComponent };
ScenarioComponent.decorators = [
    { type: Component, args: [{
                selector: 'ap-scenario',
                template: "",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
ScenarioComponent.ctorParameters = function () { return [
    { type: undefined, decorators: [{ type: Inject, args: [SANDBOX_LOADER,] },] },
    { type: Compiler, },
    { type: Injector, },
    { type: ViewContainerRef, },
]; };
ScenarioComponent.propDecorators = {
    'selectedSandboxAndScenarioKeys': [{ type: Input },],
};
//# sourceMappingURL=scenario.component.js.map